@@ -3,14 +3,14 @@ use warnings;
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '2.12.0';
+$Git::Hooks::CheckJira::VERSION = '2.13.0';
 use 5.010;
 use utf8;
 use Log::Any '$log';
 use Git::Hooks;
 use Git::Repository::Log;
 use Path::Tiny;
-use List::MoreUtils qw/uniq/;
+use List::MoreUtils qw/last_index uniq/;
 
 my $PKG = __PACKAGE__;
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
@@ -205,18 +205,24 @@ EOS
 
         # global JQL
         if (my $jql = $git->get_config($CFG => 'jql')) {
-            push @jqls, $jql;
+            push @jqls, $jql unless $jql eq 'undef';
         }
 
         # ref-specific JQL
         foreach my $refjql (reverse $git->get_config($CFG => 'ref-jql')) {
             my ($match_ref, $jql) = split ' ', $refjql, 2;
             if ($ref =~ $match_ref) {
-                push @jqls, $jql;
+                push @jqls, $jql unless $jql eq 'undef';
                 last;
             }
         }
 
+        # AND JQLs
+        if (my @and_jql = $git->get_config($CFG => 'and-jql')) {
+            my $first = 1 + last_index {$_ eq 'undef'} @and_jql;
+            push @jqls, @and_jql[$first .. $#and_jql];
+        }
+
         # JQL terms for the deprecated configuration options
         foreach my $option (qw/project issuetype status/) {
             if (my @values = $git->get_config($CFG => $option)) {
@@ -608,7 +614,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 2.12.0
+version 2.13.0
 
 =head1 SYNOPSIS
 
@@ -822,6 +828,9 @@ which must match all cited issues. For example, you may want to:
 This is a scalar option. Only the last JQL expression will be used to check the
 issues.
 
+The special value 'undef' can be used to disable the option, making it possible
+to disable it locally.
+
 =head2 ref-jql REF JQL
 
 You may impose restrictions on specific branches (or, more broadly, any
@@ -837,10 +846,37 @@ expression starting with a caret (C<^>), which is kept as part of the regexp
 This is a scalar option. Only the last JQL expression will be used to check the
 issues.
 
+The special value 'undef' can be used to disable the option, making it possible
+to disable it locally.
+
 Note, though, that if there is a global JQL specified by the
 B<githooks.checkjira.jql> option it will be checked separately and both
 expressions must validate the issues matching REF.
 
+=head2 and-jql JQL
+
+Unlike the B<jql> option, this one is multi-valued. All JQL terms specified with
+this option are ANDed together with the last B<jql> expression and with the
+B<ref-jql> expression, if they exist.
+
+It is useful, for instance, when you want to specialize a default JQL with new
+terms.  Suppose you have a global B<jql> option with some general requirements
+that all Jira issues must fulfill, like being of particular types and in
+specific statuses:
+
+  [githooks "checkjira"]
+    jql = issuetype IN (Bug, Story) AND status IN ("In progress", "In testing")
+
+Moreover, you may have several repositories, each one associated with a
+particular Jira project. Then, you can AND more terms to the global JQL like
+this in a repository:
+
+  [githooks "checkjira"]
+    and-jql = project = ABC
+
+The special value 'undef' can be used to reset the option, effectively making
+any previous values be forgotten so that you can start anew to add terms to it.
+
 =head2 require BOOL
 
 By default, the log must reference at least one JIRA issue. You can
@@ -1086,7 +1122,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2020 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
